Any form of contributing is appreciated; Inclunding but not limited to:

* Expanding the test suit.
* Packaging for more GNU/Linux distributions.
* Packaging for [Homebrew](https://brew.sh) and [Msys2](https://www.msys2.org).
